	<template>
		<view>
			<uni-segmented-control :current="current" :values="items" @clickItem="onClickItem">
			</uni-segmented-control>
			<view class="content">
				<view v-if="current === 0" class="headerstyle">
					<view class="itemstyle">
						<uni-forms label-width="120">
							<uni-forms-item label="缓存架编号">
								<uni-easyinput type="text" :focus="!addressFocus" v-model="stationcode"
									placeholder="请扫瞄缓存架编号" ref='midInput' @input="inputChangebarcode" />
							</uni-forms-item>
							<uni-forms-item label="物料类型">
									<uni-easyinput type="text" :focus="!addressFocus" v-model="PalletCode"
										placeholder="请扫描物料类型" ref='midInput' @input="inputChangebarcode" />
							</uni-forms-item>
							<uni-forms-item>
								<button @click="inbound" type="primary" size="default"
									style="margin-top: 2%;">出库确认</button>
							</uni-forms-item>
						</uni-forms>
					</view>
				</view>
			</view>
			<u-toast ref="uToast" />
		</view>
	</template>

	<script>
		const innerAudioContext = uni.createInnerAudioContext();
		export default {
			data() {
				return {
					items: ['出库'],
					current: 0,
					matTotal: [],
					matInfos: [],
					orderNo: "",
					label: "",
					orderDetail: [],
					focus: false,
					barcode: "",
					materSn: "",
					sns: [],
					addressFocus: false,
					materialtype: "",
					stationcode: "",
					address: "",
					check: true,
					value: "",
					matInfo: [],
					value2: "",
					matTotals: [],
					rangs: [] // 存储物料类型数据
				}
			},
			onShow() {
				this.getMaterialTypes(); // 页面显示时获取物料类型数据
			},
			onLoad(res) {
				this.focus = false;
				this.addressFocus = false;
				this.orderNo = res.orderNo;
				this.label = "单据编号：" + this.orderNo;
				this.getData();
			},
			methods: {
				voiceSpeech(src) {
					innerAudioContext.src = src;
					innerAudioContext.play();
				},

				updateFocus() {
					this.$nextTick(() => {
						this.materSn = '';
						if (!this.focus) {
							this.focus = true;
						}
					});
				},
				barcodeFocus() {
					this.barcode = '';
					if (this.focus) {
						this.focus = false;
					}
				},
				getData() {
					var postData = this.orderNo;

					this.$u.post('/api/InboundOrder/GetInboundOrderDetail', postData).then((res) => {
						if (res.status) {
							this.orderDetail = res.data;
							if (this.orderDetail.length > 3) {
								this.loadVisible = true;
							}
						}
					})
				},
				getMaterialTypes() {
					this.$u.post('/api/MaterielInfo/GetMaterialTypes').then((res) => {
						if (res.status) {
							console.log(res.data);
							this.rangs = res.data.map(item => {
								return {
									value: item.number, // 假设后端返回的数据中有 id 和 name 字段
									text: item.number
								};
							});
						}
					}).catch(err => {
						this.$refs.uToast.show({
							title: err.message,
							type: "error"
						});
					});
				},
				onClickItem(e) {
					this.focus = false;
					this.addressFocus = false;
					if (this.current !== e.currentIndex) {
						this.current = e.currentIndex;
						if (this.current == 2) {
							this.getData();
						}
					}
				},
				barcodeInput() {
					this.$nextTick(function(x) {
						if (this.barcode.length > 0) {
							this.focus = true;
						}
					})
				},
				inbound() {
					var postData = {
						MainData: {
							"stationcode": this.stationcode,
							"PalletCode": this.PalletCode,
						}
					}
					this.$u.post('/api/Task/OutboundTasks', postData).then(res => {
						if (res.status) {
							uni.$showMsg("任务添加成功");
							this.stationcode = ""; // 清空缓存架编号
							this.PalletCode = ""; // 清空物料类型
						} else {
							this.$refs.uToast.show({
								title: res.message,
								type: "error"
							})
						}
					}).catch(err => {
						this.$refs.uToast.show({
							title: err.message,
							type: "error"
						})
					})
				},
				inputChangebarcode() {
					this.addressFocus = false;
					this.$nextTick(function(x) {
						if (this.stationcode != '') {
							this.addressFocus = true;
						}
					})
				},
			}
		}
	</script>

	<style lang="scss">
		@import '@/common/uni-ui.scss';

		.content {
			display: flex;
			height: 150px;
		}

		.content-text {
			font-size: 14px;
			color: #666;
		}

		.itemstyle {
			margin-top: 30px;
			margin-left: 5%;
		}

		.headerstyle {
			width: 90%;
		}
	</style>